# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_message.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61gent_message.proto\x12\rcommunication\"\xb7\x01\n\rProtoDataItem\x12\x14\n\x0c\x64\x61ta_type_id\x18\x01 \x02(\x05\x12\x13\n\x0b\x62ool_values\x18\x02 \x03(\x08\x12\x16\n\nint_values\x18\x03 \x03(\x05\x42\x02\x10\x01\x12\x17\n\x0blong_values\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x18\n\x0c\x66loat_values\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x19\n\rdouble_values\x18\x06 \x03(\x01\x42\x02\x10\x01\x12\x15\n\rstring_values\x18\x07 \x03(\t\"\x80\x02\n\nNestedItem\x12\x14\n\x0c\x64\x61ta_type_id\x18\x01 \x02(\x05\x12\x13\n\x0b\x62ool_values\x18\x02 \x03(\x08\x12\x16\n\nint_values\x18\x03 \x03(\x05\x42\x02\x10\x01\x12\x17\n\x0blong_values\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x18\n\x0c\x66loat_values\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x19\n\rdouble_values\x18\x06 \x03(\x01\x42\x02\x10\x01\x12\x15\n\rstring_values\x18\x07 \x03(\t\x12\x1b\n\x0ftime_series_ids\x18\x08 \x03(\x05\x42\x02\x10\x01\x12-\n\ncomponents\x18\t \x03(\x0b\x32\x19.communication.NestedItem\"\x99\x01\n\x0cProtoMessage\x12\x11\n\tsender_id\x18\x01 \x02(\x03\x12\x13\n\x0breceiver_id\x18\x02 \x02(\x03\x12\x30\n\ndata_items\x18\x03 \x03(\x0b\x32\x1c.communication.ProtoDataItem\x12/\n\x0cnested_items\x18\x04 \x03(\x0b\x32\x19.communication.NestedItemB$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05\x41gent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Agent'
  _globals['_PROTODATAITEM'].fields_by_name['int_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['int_values']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM'].fields_by_name['long_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['long_values']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM'].fields_by_name['float_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['float_values']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM'].fields_by_name['double_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['double_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['int_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['int_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['long_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['long_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['float_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['float_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['double_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['double_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['time_series_ids']._options = None
  _globals['_NESTEDITEM'].fields_by_name['time_series_ids']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM']._serialized_start=39
  _globals['_PROTODATAITEM']._serialized_end=222
  _globals['_NESTEDITEM']._serialized_start=225
  _globals['_NESTEDITEM']._serialized_end=481
  _globals['_PROTOMESSAGE']._serialized_start=484
  _globals['_PROTOMESSAGE']._serialized_end=637
# @@protoc_insertion_point(module_scope)
