# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eservices.proto\x12\rcommunication\"\"\n\rScheduledTime\x12\x11\n\ttime_step\x18\x01 \x02(\x03\"\x1f\n\rWarmUpMessage\x12\x0e\n\x06needed\x18\x01 \x02(\x08\"\xda\x04\n\x06Output\x12\x34\n\x0b\x61gent_types\x18\x01 \x03(\x0b\x32\x1f.communication.Output.AgentType\x12,\n\x06series\x18\x02 \x03(\x0b\x32\x1c.communication.Output.Series\x1a\x9a\x01\n\tAgentType\x12\x12\n\nclass_name\x18\x01 \x02(\t\x12\x35\n\x06\x66ields\x18\x02 \x03(\x0b\x32%.communication.Output.AgentType.Field\x1a\x42\n\x05\x46ield\x12\x10\n\x08\x66ield_id\x18\x01 \x02(\x05\x12\x12\n\nfield_name\x18\x02 \x02(\t\x12\x13\n\x0bindex_names\x18\x03 \x03(\t\x1a\xce\x02\n\x06Series\x12\x12\n\nclass_name\x18\x01 \x02(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x02(\x03\x12\x30\n\x05lines\x18\x03 \x03(\x0b\x32!.communication.Output.Series.Line\x1a\xeb\x01\n\x04Line\x12\x11\n\ttime_step\x18\x01 \x02(\x03\x12\x39\n\x07\x63olumns\x18\x02 \x03(\x0b\x32(.communication.Output.Series.Line.Column\x1a\x94\x01\n\x06\x43olumn\x12\x10\n\x08\x66ield_id\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\x12=\n\x07\x65ntries\x18\x03 \x03(\x0b\x32,.communication.Output.Series.Line.Column.Map\x1a*\n\x03Map\x12\x14\n\x0cindex_values\x18\x01 \x03(\t\x12\r\n\x05value\x18\x02 \x02(\t\"8\n\x0b\x41\x64\x64ressBook\x12\x12\n\nprocess_id\x18\x01 \x02(\x05\x12\x15\n\tagent_ids\x18\x02 \x03(\x03\x42\x02\x10\x01\x42\'\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x08Services')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\010Services'
  _globals['_ADDRESSBOOK'].fields_by_name['agent_ids']._options = None
  _globals['_ADDRESSBOOK'].fields_by_name['agent_ids']._serialized_options = b'\020\001'
  _globals['_SCHEDULEDTIME']._serialized_start=33
  _globals['_SCHEDULEDTIME']._serialized_end=67
  _globals['_WARMUPMESSAGE']._serialized_start=69
  _globals['_WARMUPMESSAGE']._serialized_end=100
  _globals['_OUTPUT']._serialized_start=103
  _globals['_OUTPUT']._serialized_end=705
  _globals['_OUTPUT_AGENTTYPE']._serialized_start=214
  _globals['_OUTPUT_AGENTTYPE']._serialized_end=368
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_start=302
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_end=368
  _globals['_OUTPUT_SERIES']._serialized_start=371
  _globals['_OUTPUT_SERIES']._serialized_end=705
  _globals['_OUTPUT_SERIES_LINE']._serialized_start=470
  _globals['_OUTPUT_SERIES_LINE']._serialized_end=705
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_start=557
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_end=705
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_start=663
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_end=705
  _globals['_ADDRESSBOOK']._serialized_start=707
  _globals['_ADDRESSBOOK']._serialized_end=763
# @@protoc_insertion_point(module_scope)
