# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: field.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x66ield.proto\x12\x08iobinary\"\xd6\x01\n\x0bNestedField\x12\x12\n\nfield_name\x18\x01 \x02(\t\x12\x11\n\tseries_id\x18\x02 \x01(\x05\x12\x16\n\nint_values\x18\x03 \x03(\x05\x42\x02\x10\x01\x12\x15\n\rstring_values\x18\x04 \x03(\t\x12\x19\n\rdouble_values\x18\x05 \x03(\x01\x42\x02\x10\x01\x12%\n\x06\x66ields\x18\x06 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x17\n\x0blong_values\x18\x07 \x03(\x03\x42\x02\x10\x01\x12\x16\n\x07is_list\x18\x08 \x01(\x08:\x05\x66\x61lseB$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05\x46ield')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'field_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Field'
  _globals['_NESTEDFIELD'].fields_by_name['int_values']._options = None
  _globals['_NESTEDFIELD'].fields_by_name['int_values']._serialized_options = b'\020\001'
  _globals['_NESTEDFIELD'].fields_by_name['double_values']._options = None
  _globals['_NESTEDFIELD'].fields_by_name['double_values']._serialized_options = b'\020\001'
  _globals['_NESTEDFIELD'].fields_by_name['long_values']._options = None
  _globals['_NESTEDFIELD'].fields_by_name['long_values']._serialized_options = b'\020\001'
  _globals['_NESTEDFIELD']._serialized_start=26
  _globals['_NESTEDFIELD']._serialized_end=240
# @@protoc_insertion_point(module_scope)
