# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_storage.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import services_pb2 as services__pb2
from fameprotobuf import input_file_pb2 as input__file__pb2
from fameprotobuf import execution_data_pb2 as execution__data__pb2
from fameprotobuf import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x64\x61ta_storage.proto\x12\x08iobinary\x1a\x0eservices.proto\x1a\x10input_file.proto\x1a\x14\x65xecution_data.proto\x1a\x0bmodel.proto\"\xa5\x01\n\x0b\x44\x61taStorage\x12\"\n\x05input\x18\x01 \x01(\x0b\x32\x13.iobinary.InputData\x12%\n\x06output\x18\x02 \x01(\x0b\x32\x15.communication.Output\x12*\n\texecution\x18\x03 \x01(\x0b\x32\x17.iobinary.ExecutionData\x12\x1f\n\x05model\x18\x04 \x01(\x0b\x32\x10.model.ModelDataB&\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x07Storage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_storage_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\007Storage'
  _globals['_DATASTORAGE']._serialized_start=102
  _globals['_DATASTORAGE']._serialized_end=267
# @@protoc_insertion_point(module_scope)
