# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x05model\"\xac\x01\n\tModelData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x39\n\x12package_definition\x18\x03 \x01(\x0b\x32\x1d.model.ModelData.JavaPackages\x1a\x45\n\x0cJavaPackages\x12\x0e\n\x06\x61gents\x18\x01 \x03(\t\x12\x12\n\ndata_items\x18\x02 \x03(\t\x12\x11\n\tportables\x18\x03 \x03(\tB$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Model')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Model'
  _globals['_MODELDATA']._serialized_start=23
  _globals['_MODELDATA']._serialized_end=195
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_start=126
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_end=195
# @@protoc_insertion_point(module_scope)
